# Block library

Block library for the WordPress editor.

## Installation

Install the module

```bash
npm install @wordpress/block-library --save
```

_This package assumes that your code will run in an **ES2015+** environment. If you're using an environment that has limited or no support for such language features and APIs, you should include [the polyfill shipped in `@wordpress/babel-preset-default`](https://github.com/WordPress/gutenberg/tree/HEAD/packages/babel-preset-default#polyfill) in your code._

## Building JavaScript for the browser

If a `view.js` file (or a file prefixed with `view`, e.g. `view-example.js`) is present in the block's directory, this file will be built along other assets, making it available to load from the browser.

This enables us to, for instance, load this file when the block is present on the page in two ways:

1.  Using the block's `render_callback`:

```php
function render_block_my_block() {
	$script_path = __DIR__ . '/my-block/view.js';

 	if ( file_exists( $script_path ) ) {
 		wp_enqueue_script(
 			'wp-block-my-block-view',
 			plugins_url( 'view.js', $script_path ),
 			array(),
 			false,
 			true
 		);
 	}
}

function register_block_my_block() {
	register_block_type(
		__DIR__ . '/my-block',
		array(
			'render_callback' => 'render_block_my_block',
		)
	);
}


add_action( 'init', 'register_block_my_block' );
```

2.  Using the `render_block` filter:

```php
function render_block_my_block() {
	$script_path = __DIR__ . '/my-block/view.js';

 	if ( file_exists( $script_path ) ) {
 		wp_enqueue_script(
 			'wp-block-my-block-view',
 			plugins_url( 'view.js', $script_path ),
 			array(),
 			false,
 			true
 		);
 	}
}

apply_filter( 'render_block', 'render_block_my_block' );
```

## API

<!-- START TOKEN(Autogenerated API docs) -->

### registerCoreBlocks

Function to register core blocks provided by the block editor.

_Usage_

```js
import { registerCoreBlocks } from '@wordpress/block-library';

registerCoreBlocks();
```

_Parameters_

-   _blocks_ `Array`: An optional array of the core blocks being registered.

<!-- END TOKEN(Autogenerated API docs) -->

## Contributing to this package

This is an individual package that's part of the Gutenberg project. The project is organized as a monorepo. It's made up of multiple self-contained software packages, each with a specific purpose. The packages in this monorepo are published to [npm](https://www.npmjs.com/) and used by [WordPress](https://make.wordpress.org/core/) as well as other software projects.

To find out more about contributing to this package or Gutenberg as a whole, please read the project's main [contributor guide](https://github.com/WordPress/gutenberg/tree/HEAD/CONTRIBUTING.md).

### Adding new blocks

⚠️ Adding new blocks to this package **requires** additional steps!

1.  Do not forget to register your new block in the [`index.js`](https://github.com/WordPress/gutenberg/blob/trunk/packages/block-library/index.js) file of this package. For example, if you were to add a new core block called `core/blinking-paragraph`, you would have to add something like:

    ```js
    // packages/block-library/src/index.js
    import * as blinkingParagraph from './blinking-paragraph';

    // Then add `blinkingParagraph` to `getAllBlocks()`
    // If it's experimental, add the following property to block.json:
    __experimental: 'true';
    ```

2.  Register your block in the `gutenberg_reregister_core_block_types()` function of the [`lib/blocks.php`](https://github.com/WordPress/gutenberg/blob/trunk/lib/blocks.php) file. Add it to the `block_folders` array if it's a [static block](https://developer.wordpress.org/block-editor/explanations/glossary/#static-block) or to the `block_names` array if it's a [dynamic block](https://developer.wordpress.org/block-editor/explanations/glossary/#dynamic-block).

<br /><br /><p align="center"><img src="https://s.w.org/style/images/codeispoetry.png?1" alt="Code is Poetry." /></p>
